@@ -8,6 +8,8 @@ use Socket;
 use Socket::Netlink qw( :DEFAULT );
 use Socket::Netlink::Route qw( :DEFAULT );
 
+use Data::Dump qw( pp );
+
 my $rtnlsock = IO::Socket::Netlink::Route->new
    or die "Cannot make netlink socket - $!";
 
@@ -15,9 +17,7 @@ my @messages;
 
 $rtnlsock->send_nlmsg( $rtnlsock->new_request(
       nlmsg_type  => RTM_GETADDR, 
-      nlmsg_flags => NLM_F_ROOT,
-
-      ifa_family => AF_INET,
+      nlmsg_flags => NLM_F_DUMP,
 ) );
 
 $rtnlsock->recv_nlmsgs( \@messages, 2**16 ) or
@@ -32,12 +32,11 @@ foreach my $message ( @messages ) {
       printf "Got reply type=%d flags=%04x seq=%d pid=%d\n",
          $message->nlmsg_type, $message->nlmsg_flags, $message->nlmsg_seq, $message->nlmsg_pid;
 
-      printf "  family=%d prefixlen=%d flags=%04x scope=%d index=%d; rtattrs:\n",
+      printf "  family=%d prefixlen=%d flags=%04x scope=%d index=%d\n",
          $message->ifa_family, $message->ifa_prefixlen, $message->ifa_flags, $message->ifa_scope, $message->ifa_index;
 
-      my $attrs = $message->nlattrs;
-      foreach my $name ( sort keys %$attrs ) {
-         printf "    %s => %s\n", $name, $attrs->{$name};
-      }
+      printf "  prefix=%s; rtattrs:\n", $message->prefix;
+
+      print pp( $message->nlattrs ) . "\n";
    }
 }
